package `in`.lending.finbox_lending_plugin

import android.app.Activity
import android.content.Context
import android.content.Intent
import androidx.core.app.ActivityCompat
import com.google.gson.GsonBuilder
import `in`.finbox.lending.hybrid.FinBoxLending
import `in`.finbox.lending.hybrid.ToolbarConfig
import `in`.finbox.lending.hybrid.models.FinBoxJourneyResult
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.PluginRegistry
import java.util.*

class FinBoxLendingPlugin : FlutterPlugin, MethodChannel.MethodCallHandler, ActivityAware,
    PluginRegistry.ActivityResultListener {

    companion object {
        const val FINBOX_JOURNEY_RESULT = "finbox_result"
    }

    private lateinit var lendingChannel: MethodChannel
    private var activity: Activity? = null
    private lateinit var context: Context
    private lateinit var finBoxLending: FinBoxLending
    override fun onAttachedToEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        // Get context
        context = binding.applicationContext
        // Get channel
        lendingChannel =
            MethodChannel(binding.binaryMessenger, "in.finbox.lending/hybrid")
        lendingChannel.setMethodCallHandler(this)
    }

    override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        lendingChannel.setMethodCallHandler(null)
    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        // Get arguments
        when (call.method) {
            "initSdk" -> {
                initSdk(
                    call.argument("env")!!,
                    call.argument("apiKey")!!,
                    call.argument("customerID")!!,
                    call.argument("token")!!,
                    call.argument("toolbarTitle"),
                    call.argument("hidePoweredBy"),
                    call.argument("creditLineAmount")
                )
            }

            "startLending" -> {
                startLendingActivity()
            }
        }
    }

    /**
     * Initialize SDK
     */
    private fun initSdk(
        env: String,
        apiKey: String,
        customerID: String,
        token: String,
        toolbarTitle: String?,
        hidePoweredBy: Boolean?,
        creditLineAmount: String?
    ) {

        finBoxLending = FinBoxLending.Builder(context)
            .setLendingEnvironment(env)
            .setFinBoxApiKey(apiKey)
            .setCustomerId(customerID)
            .setUserToken(token)
            .apply {
                if (creditLineAmount.isNullOrBlank()) {
                    // Credit line amount is empty
                } else {
                    this.setCreditLineAmount(creditLineAmount.toFloat())
                    this.setCreditLineTransactionId(UUID.randomUUID().toString())
                }
                if (toolbarTitle.isNullOrBlank()) {
                    // Toolbar title is empty
                } else {
                    this.setToolBarConfig(ToolbarConfig(toolbarTitle))
                    this.showToolbar(false)
                }
                if (hidePoweredBy == true) {
                    this.hidePoweredBy(true)
                }
            }.build()
    }

    private fun startLendingActivity() {
        this.activity?.let {
            ActivityCompat.startActivityForResult(
                it,
                finBoxLending.getLendingIntent(context),
                123,
                null
            )
        }
    }

    override fun onAttachedToActivity(binding: ActivityPluginBinding) {
        this.activity = binding.activity
        binding.addActivityResultListener(this)
    }

    override fun onDetachedFromActivityForConfigChanges() {
    }

    override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
        binding.addActivityResultListener(this)
    }

    /**
     * Parse journey result
     */
    private fun parseData(data: Intent?) {
        val result = data?.extras?.getParcelable<FinBoxJourneyResult>(FINBOX_JOURNEY_RESULT)
        result?.let { finBoxPayLoad ->
            sendResult(finBoxPayLoad)
        } ?: sendResult(FinBoxJourneyResult("", "", "Something went wrong"))
    }

    override fun onDetachedFromActivity() {
        this.activity = null
    }

    /**
     * Send result
     */
    private fun sendResult(data: FinBoxJourneyResult) {
        val gson = GsonBuilder().serializeNulls().create()
        lendingChannel.invokeMethod("getJourneyResult", gson.toJson(data))
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?): Boolean {
        parseData(data)
        return true
    }
}


