import Flutter
import UIKit
import FinBoxLending

public class FinBoxLendingPlugin: NSObject, FlutterPlugin {
    
    // Flutter method channel
    static var channel: FlutterMethodChannel? = nil
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        channel = FlutterMethodChannel(name: "in.finbox.lending/hybrid", binaryMessenger: registrar.messenger())
        let instance = FinBoxLendingPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel!)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case "initSdk":
            guard let args = call.arguments else {
                print("No arguments are returned")
                return
            }
            if let myArgs = args as? [String: Any],
               let env = myArgs["env"] as? String,
               let apiKey = myArgs["apiKey"] as? String,
               let customerID = myArgs["customerID"] as? String,
               let token = myArgs["token"] as? String{
                
                let toolbarTitle = myArgs["toolbarTitle"] as? String
                let hidePoweredBy = myArgs["hidePoweredBy"] as? Bool ?? false
                let creditLineAmount = myArgs["creditLineAmount"] as? Float ?? 0.0
                
                let _ = FinBoxLending.Builder()
                    .environment(env: env)
                    .apiKey(key: apiKey)
                    .customerID(id: customerID)
                    .userToken(token: token)
                //                    .setSplashIcon(<DRAWABLE>)
                //                    .setToolbarIcon(<DRAWABLE>)
                    .hidePoweredBy(hide: hidePoweredBy)
                    .creditLineAmount(amount: creditLineAmount)
                    .dcEnabled(enabled: false)
                    .build()
                
            }
        case "startLending":
            // Create a View Controller
            let vc = FinBoxViewController()
            
            // Get access to the window
            let keyWindow = UIApplication
                .shared
                .connectedScenes
                .flatMap { ($0 as? UIWindowScene)?.windows ?? [] }
                .last { $0.isKeyWindow }
            
            // Get the view controller at root
            let viewController = keyWindow?.rootViewController
            
            // Attach the view controller to the root
            let nav = UINavigationController(rootViewController: vc)
            
            nav.modalPresentationStyle = .overFullScreen
            
            // Show the view on the screen
            viewController?.present(nav, animated: true,completion: nil)
            
        default:
            result(FlutterMethodNotImplemented)
        }
    }
}
