import 'package:flutter/services.dart';

class FinBoxLendingPlugin {
  static const platform = MethodChannel('in.finbox.lending/hybrid');

  /// Configure basic details required before starting Lending journey
  ///
  /// Pass an environment key named [env] to set the configuration to PROD or UAT.
  /// The API key name [apiKey] is used to authenticate the client.
  /// [customerID] is an unique identifier for the customer.
  /// [token] is used to authenticate the customer and the session.
  /// In case you want to show simple toolbar, pass the [toolbarTitle] text.
  /// To invoke Credit line journey instead of Personal Loan or Business loan journeys,
  /// pass [creditLineAmount]
  static Future initSdk(
      String env,
      String apiKey,
      String customerID,
      String token,
      String? toolbarTitle,
      bool? hidePoweredBy,
      String? creditLineAmount) async {
    try {
      await platform.invokeMethod('initSdk', <String, dynamic>{
        'env': env,
        'apiKey': apiKey,
        'customerID': customerID,
        'token': token,
        'toolbarTitle': toolbarTitle,
        'hidePoweredBy': hidePoweredBy,
        'creditLineAmount': creditLineAmount
      });
    } on PlatformException catch (e) {
      print("Error on launching lending journey ${e.message}");
    }
  }

  /// Begin the lending journey
  static Future startLending() async {
    try {
      await platform.invokeMethod('startLending', <String, dynamic>{});
    } on PlatformException catch (e) {
      print("Error on launching lending journey ${e.message}");
    }
  }
}
